@@ -912,7 +912,7 @@ _gnutls_parse_general_name (ASN1_TYPE src, const char *src_name,
 			    unsigned int *ret_type, int othername_oid)
 {
   unsigned int len;
-  char nptr[MAX_NAME_SIZE];
+  char nptr[ASN1_MAX_NAME_SIZE];
   int result;
   opaque choice_type[128];
   gnutls_x509_subject_alt_name_t type;
@@ -1604,7 +1604,7 @@ gnutls_x509_crt_get_extension_info (gnutls_x509_crt_t cert, int indx,
 {
   int result;
   char str_critical[10];
-  char name[MAX_NAME_SIZE];
+  char name[ASN1_MAX_NAME_SIZE];
   int len;
 
   if (!cert)
@@ -1675,7 +1675,7 @@ gnutls_x509_crt_get_extension_data (gnutls_x509_crt_t cert, int indx,
 				    void *data, size_t * sizeof_data)
 {
   int result, len;
-  char name[MAX_NAME_SIZE];
+  char name[ASN1_MAX_NAME_SIZE];
 
   if (!cert)
     {
@@ -1869,7 +1869,7 @@ gnutls_x509_dn_get_rdn_ava (gnutls_x509_dn_t dn,
   ASN1_TYPE rdn, elem;
   long len;
   int lenlen, remlen, ret;
-  char rbuf[MAX_NAME_SIZE];
+  char rbuf[ASN1_MAX_NAME_SIZE];
   unsigned char cls, *ptr;
 
   iava++;
@@ -2305,18 +2305,47 @@ gnutls_x509_crt_check_revocation (gnutls_x509_crt_t cert,
 }
 
 /**
-  * gnutls_x509_crt_verify_data - This function will verify the given signed data.
-  * @crt: Holds the certificate
-  * @flags: should be 0 for now
-  * @data: holds the data to be signed
-  * @signature: contains the signature
-  *
-  * This function will verify the given signed data, using the
-  * parameters from the certificate.
-  *
-  * Returns: In case of a verification failure 0 is returned, and 1 on
-  * success.
-  **/
+ * gnutls_x509_crt_get_verify_algorithm - get hash algorithm used to verify signature.
+ * @crt: Holds the certificate
+ * @signature: contains the signature
+ * @hash: The result of the call with the hash algorithm used for signature
+ *
+ * This function will read the certifcate and the signed data to
+ * determine the hash algorithm used to generate the signature.
+ *
+ * Returns: the 0 if the hash algorithm is found. A negative value is
+ * returned on error.
+ *
+ * Since: 2.8.0
+ **/
+int
+gnutls_x509_crt_get_verify_algorithm (gnutls_x509_crt_t crt,
+				      const gnutls_datum_t * signature,
+				      gnutls_digest_algorithm_t *hash)
+{
+  if (crt == NULL)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
+
+  return _gnutls_x509_verify_algorithm ((gnutls_mac_algorithm_t *) hash,
+					signature, crt);
+}
+
+/**
+ * gnutls_x509_crt_verify_data - verify the given signed data.
+ * @crt: Holds the certificate
+ * @flags: should be 0 for now
+ * @data: holds the data to be signed
+ * @signature: contains the signature
+ *
+ * This function will verify the given signed data, using the
+ * parameters from the certificate.
+ *
+ * Returns: In case of a verification failure 0 is returned, and 1 on
+ * success.
+ **/
 int
 gnutls_x509_crt_verify_data (gnutls_x509_crt_t crt, unsigned int flags,
 			     const gnutls_datum_t * data,
@@ -2330,7 +2359,43 @@ gnutls_x509_crt_verify_data (gnutls_x509_crt_t crt, unsigned int flags,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  result = _gnutls_x509_verify_signature (data, signature, crt);
+  result = _gnutls_x509_verify_signature (data, NULL, signature, crt);
+  if (result < 0)
+    {
+      gnutls_assert ();
+      return 0;
+    }
+
+  return result;
+}
+
+/**
+ * gnutls_x509_crt_verify_hash - verify the given signed digest
+ * @crt: Holds the certificate
+ * @flags: should be 0 for now
+ * @hash: holds the hash digest to be verified
+ * @signature: contains the signature
+ *
+ * This function will verify the given signed digest, using the
+ * parameters from the certificate.
+ *
+ * Returns: In case of a verification failure 0 is returned, and 1 on
+ * success.
+ **/
+int
+gnutls_x509_crt_verify_hash (gnutls_x509_crt_t crt, unsigned int flags,
+			     const gnutls_datum_t * hash,
+			     const gnutls_datum_t * signature)
+{
+  int result;
+
+  if (crt == NULL)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
+
+  result = _gnutls_x509_verify_signature (NULL, hash, signature, crt);
   if (result < 0)
     {
       gnutls_assert ();
@@ -2384,7 +2449,7 @@ gnutls_x509_crt_get_crl_dist_points (gnutls_x509_crt_t cert,
   int result;
   gnutls_datum_t dist_points = { NULL, 0 };
   ASN1_TYPE c2 = ASN1_TYPE_EMPTY;
-  char name[MAX_NAME_SIZE];
+  char name[ASN1_MAX_NAME_SIZE];
   int len;
   gnutls_x509_subject_alt_name_t type;
   uint8_t reasons[2];
@@ -2498,7 +2563,7 @@ gnutls_x509_crt_get_key_purpose_oid (gnutls_x509_crt_t cert,
 				     int indx, void *oid, size_t * sizeof_oid,
 				     unsigned int *critical)
 {
-  char tmpstr[MAX_NAME_SIZE];
+  char tmpstr[ASN1_MAX_NAME_SIZE];
   int result, len;
   gnutls_datum_t id;
   ASN1_TYPE c2 = ASN1_TYPE_EMPTY;
